@@ -63,6 +63,7 @@ sub subcategories
 {
     my $self = shift;
     my @subs;
+    return () if ! $self->row;
     for($self->row->categories)
     {
         push @subs, Strehler::Meta::Category->new('row', $_);
@@ -309,6 +310,7 @@ sub save_form
 sub ext_name
 {
     my $self = shift;
+    return undef if(! $self->row);
     my $category = $self->row->category;
     if($self->row->parent)
     {
@@ -317,6 +319,17 @@ sub ext_name
     return $category;
 }
 
+sub check_role
+{
+    my $self = shift;
+    my $role = shift;
+    if(! config->{Strehler}->{admin_secured})
+    {
+        return 1;
+    }
+    return ($role eq 'admin');
+}
+
 
 1;
 
